@@ -8,7 +8,7 @@ BEGIN {
 
     use Excel::Template::Base;
 
-#    use Unicode::String;
+UNI_YES     use Unicode::String;
 }
 
 # This is a helper object. It is not instantiated by the user,
@@ -31,17 +31,17 @@ sub resolve
     my $self = shift;
     my ($context) = @_;
 
-#    my $t = Unicode::String::utf8('');
-    my $t = '';
+UNI_YES    my $t = Unicode::String::utf8('');
+UNI_NO    my $t = '';
 
     for my $tok (@{$self->{STACK}})
     {
         my $val = $tok;
         $val = $val->resolve($context)
-            if Excel::Template::Factory::isa($val, 'VAR');
+            if Excel::Template::Factory::is_embedded( $val );
 
-#        $t .= Unicode::String::utf8("$val");
-        $t .= $val;
+UNI_YES        $t .= Unicode::String::utf8("$val");
+UNI_NO        $t .= $val;
     }
 
     return $t;
@@ -72,7 +72,7 @@ Excel::Template::TextObject
 
 =head1 AUTHOR
 
-Rob Kinyon (rkinyon@columbus.rr.com)
+Rob Kinyon (rob.kinyon@gmail.com)
 
 =head1 SEE ALSO
 
